@@ -24,8 +24,8 @@ class Cemotion:
         #保存中文词典路径
         dictionary_path = current_path + '/models/requirements/big_Chinese_Words_Map.dict'        
         #检测所需文件是否存在，判断是否下载
-        download_from_url(dictionary_path, 'https://www.cyberlight.xyz/static/file/cemotion/big_Chinese_Words_Map.dict')
-        download_from_url(model_path, 'https://www.cyberlight.xyz/static/file/cemotion/rnn_emotion_1.0.h5')
+        download_from_url('https://www.cyberlight.xyz/static/file/cemotion/big_Chinese_Words_Map.dict', dictionary_path)
+        download_from_url('https://www.cyberlight.xyz/static/file/cemotion/rnn_emotion_1.0.h5', model_path)
         #加载rnn模型
         self.__rnn = tf.keras.models.load_model(model_path)
         #加载数据集实例
